pub struct Context { /* private fields */ }Expand description
Nix context for managing library state.
This is the root object for all Nix operations. It manages the lifetime of the Nix C API context and provides automatic cleanup.
Implementations